import moment from 'moment'
import CardRepository from '../Repositories/CardsRepository.js'
import md5 from 'md5'
import { log } from './LogController.js'
import { cardTokenRequest } from './../Requests/RequestModule.js'
import { getRetailGeneralParamsBackend } from './RetailParamsController.js'


const getCards = async function (body) {
    return await CardRepository.getCards(body)
}

const getCardStatus = async function ({ CDCONSUMIDOR, consDetails }) {
    return await CardRepository.getCardStatus(CDCONSUMIDOR, consDetails)
}

const toggleCardStatus = async function ({ IDSITCONSUMI, CDCONSUMIDOR, consDetails }) {
    return await CardRepository.toggleCardStatus(IDSITCONSUMI, CDCONSUMIDOR, consDetails)
}

const registerCreditCard = async function (body) {
    try {
        let paymentPlatform = await getPaymentPlatform(body.CDFILIAL)
        let onlinePaymentInfo = await getOnlinePaymentInfo(body.CDFILIAL)
        let creditCard = {}
        let dtexp = moment(body.EXPDATE, 'MM/YYYY')

        let flagCode = getCardFlag(body.FLAG, 'code')
        if (!flagCode) {
            return { error: true, message: 'Bandeira inválida' }
        }

        let NRSEQBANDEIRA = await CardRepository.getNrseqbandeira(flagCode)
        if (!NRSEQBANDEIRA) {
            return { error: true, message: 'Bandeira e-Sitef não encontrada! Verifique a parametrização.' }
        }
        if (!NRSEQBANDEIRA.CDTIPORECE) {
            return { error: true, message: 'Bandeira e-Sitef não possui tipo de recebimento cadastrado! Verifique a parametrização.' }
        }
        NRSEQBANDEIRA = NRSEQBANDEIRA.NRSEQBANDEIRA

        /* 
            Adicionar validação de cartão de credito
        */
        const CDCARTCRED = await CardRepository.getNewCardCode()
        console.log(body.CDCONSUMIDOR)
        // pega os ultimos 20 digitos de body.CDCONSUMIDOR
        const CDCONSUMIDOR = body.CDCONSUMIDOR.substr(-20)
        const DSTOKEN = await getCardToken(body.NUMBERS, body.EXPDATE, body.CVV, body.FLAG, CDCONSUMIDOR)
        if (!DSTOKEN) {
            return { error: true, message: 'Falha ao cadastrar o cartão! Verifique os dados e tente novamente.' }
        }

        const NRULTNUM = body.NUMBERS.substr(-4)
        const stringToMd5 = NRULTNUM + dtexp.format('YYYY') + dtexp.format('MM') + body.CVV


        creditCard = {
            CDCARTCRED,
            DSTOKEN,
            IDTPCARTCRED: body.DEFAULT ? 'P' : 'O',
            CDCONSUMIDOR: body.CDCONSUMIDOR,
            CDCLIENTE: body.CDCLIENTE,
            NMTITULAR: body.HOLDERNAME,
            NRULTNUM,
            NRSEQBANDEIRA,
            DTEXPIRACAO: dtexp.endOf('month').format('DD/MM/YY'),
            CARTCREDMD5: md5(stringToMd5)
        }

        let checkDuplicatedCreditCardToken = await CardRepository.checkDuplicatedCreditCardToken(creditCard.DSTOKEN)
        if (checkDuplicatedCreditCardToken) {
            return { error: true, message: 'Cartão já cadastrado!' }
        }

        await CardRepository.storeCreditCardToken(creditCard)

        if (body.DEFAULT) {
            await CardRepository.setAllCreditCardsToFlagO(body.CDCLIENTE, body.CDCONSUMIDOR)
            await CardRepository.setCreditCardToFlagP(creditCard.CDCARTCRED)
        }

        return { error: false, message: 'Cartão cadastrado com sucesso!' }
    } catch (error) {
        log({ type: 'error', message: error.message })
        return {
            error: true,
            message: 'Falha ao cadastrar cartão!'
        }
    }
}

const deleteCreditCard = async function (body) {
    try {
        const CDCARTCRED = body.CDCARTCRED
        await CardRepository.deleteCreditCard(CDCARTCRED)
        return { error: false, message: 'Cartão deletado com sucesso!' }

    } catch (error) {

        log({ type: 'error', message: error.message })
        return { error: true, message: 'Falha ao deletar o cartão' }

    }
}
const getPaymentPlatform = async function (CDFILIAL) {
    return CardRepository.getPaymentPlatform(CDFILIAL)
}

const getOnlinePaymentInfo = async function (CDFILIAL) {
    return CardRepository.getOnlinePaymentInfo(CDFILIAL)
}

function getCardFlag (flag, param) {
    const flags = {
        FLAG_VISA: {code: '1', name: 'visa'},
        FLAG_MASTERCARD: {code: '2', name: 'mastercard'},
        FLAG_MASTER: {code: '2', name: 'master'},
        FLAG_AMEX: {code: '3', name: 'amex'},
        FLAG_HIPERCARD: {code: '5', name: 'hipercard'},
        FLAG_AURA: {code: '6', name: 'aura'},
        FLAG_DINERS: {code: '33', name: 'diners'},
        FLAG_ELO: {code: '41', name: 'elo'},
        FLAG_ALELO: {code: '224', name: 'alelo'},
        FLAG_SODEXO: {code: '281', name: 'sodexo'}
    }
    let result = null
    if (param === 'code') {
        Object.keys(flags).forEach(e => {
           if (flags[e].name === flag) {
                result = flags[e].code
           }
        })
    }

    if (param === 'name') {
        Object.keys(flags).forEach(e => {
            if (flags[e].code === flag) {
                 result = flags[e].name
            }
         })
    }

    if (!result) {
        return null
    }

    return result
}

async function getCardToken (cardNumber, cardExpiration, cardCVV, authorizer, customerId) {
    const retailParams = await getRetailGeneralParamsBackend()
    const merchantId = retailParams?.MERCHANTID ? retailParams.MERCHANTID : ''
    const merchantKey = retailParams?.MERCHANTKEY ? retailParams.MERCHANTKEY : ''
    const paymentCompany = retailParams?.PAYMENTCOMPANY ? retailParams.PAYMENTCOMPANY : ''

    const payload = {
        paymentCompany, 
        credentials: { merchantId, merchantKey },
        authorizer,
        customerId,
        card: {
            number: cardNumber,
            expiryDate: cardExpiration.replace('/', ''),
            securityCode: cardCVV,
        }
    }

    const uri = 'card/store'

    try {
        const res = await cardTokenRequest(uri, payload)
        if (res?.data?.result?.token) {
            return res.data.result.token
        }
    } catch (error) {
        console.log(error)
        return null
    }
}

function getFakeToken () {
    const characters = 'abcdefghijklmnopqrstuvwxyz0123456789'
    let block = [8, 4, 4, 4, 12]
    let token = ''
    block.forEach(e => {
        for (let i = 0; i < e; i++) {
            token += characters.charAt(Math.floor(Math.random() * characters.length))
        }
        token += '-'
    })
    token = token.slice(0, token.length - 1)
    return token
}

export default { 
    getCards,
    getCardStatus,
    toggleCardStatus,
    registerCreditCard,
    deleteCreditCard,
    getPaymentPlatform,
    getOnlinePaymentInfo
}
