import { executeQuery } from '../Connection/QueriesExecutor.js'

const checkConsumerDetails = async function (consDetails) {
    const { CDCLIENTE, NRCPFRESPCON } = consDetails
    const details = await executeQuery({sql: 'CHECK_CONSUMER_DETAILS',
        binds: { CDCLIENTE, NRCPFRESPCON },
        rawReturn: true
    })

    return details
}

const getCardRechargeDetails = async function (consDetails) {
    const { CDFILIAL, CDCLIENTE, NRCPFRESPCON } = consDetails
    const result = await executeQuery({sql: 'GET_RECHARGE_GRID',
        binds: { CDCLIENTE, NRCPFRESPCON, CDFILIAL },
        rawReturn: true
    })

    return result
}

const getNewCode = async function (body) {
    const binds = { ...body }
    const result = await executeQuery({
        rawReturn: true,
        binds,
        newCode: true
    })
    return result
}

const insertTransaction = async function (paramsTransaction) {
    const result = await executeQuery({
        sql: 'INSERT_TRANSACAO',
        binds: { ...paramsTransaction, NRNIT: null },
        rawReturn: true
    })

    return result
}

const insertTransactionConsumer = async function (paramsTransactionConsumer) {
    const result = await executeQuery({
        sql: 'INSERT_TRANSACAOCONS',
        binds: { ...paramsTransactionConsumer },
        rawReturn: true
    })

    return result
}

const updateTransaction = async function (paramsTransactionUpdate, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'UPDATE_TRANSACAO',
        binds: { ...paramsTransactionUpdate },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const isFirstInsertion = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'IS_FIRST_INSERTION',
        binds: { ...params },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const getCurrentBalance = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'GET_EXTRATOCONS_VRSALDCONEXT',
        binds: { ...params },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const getNRSEQMOVEXT = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'GET_NRSEQMOVEXT',
        binds: { ...params },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const insertExtratoCons = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'INSERT_EXTRATOCONS',
        binds: { ...params },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

export default { checkConsumerDetails, getCardRechargeDetails, getNewCode, insertTransaction, insertTransactionConsumer, updateTransaction, isFirstInsertion, getCurrentBalance, getNRSEQMOVEXT, insertExtratoCons }