import { executeQuery } from '../Connection/QueriesExecutor.js'

const getTransactionDateF = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'GET_TRANSACTION_DATE_F',
        binds: { ...params },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const getConsumerNrorg = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'GET_CONSUMER_NRORG',
        binds: { ...params },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const getSaldoAllFamilies = async function (params, autoCommit = true, connectionKey) {
    if (params.CDCLIENTE === '') {
        params.TCDCLIENTE = 'T'
    } else {
        params.TCDCLIENTE = ' '
    }
    if (params.CDCONSUMIDOR === '') {
        params.TCDCONSUMIDOR = 'T'
    } else {
        params.TCDCONSUMIDOR = ' '
    }

    const result = await executeQuery({
        sql: 'GET_SALDO_ALL_FAMILIES',
        binds: {
            CDCLIENTE: params.CDCLIENTE,
            TCDCLIENTE: params.TCDCLIENTE,
            CDCONSUMIDOR: params.CDCONSUMIDOR,
            TCDCONSUMIDOR: params.TCDCONSUMIDOR,
            DTMOVEXTCONS: params.DTMOVEXTCONS
        },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })
    
    return result
}

const getSaldoForFamilie = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'GET_SALDO_FOR_FAMILIES',
        binds: {
            CDCLIENTE: params.CDCLIENTE,
            CDCONSUMIDOR: params.CDCONSUMIDOR,
            CDFAMILISALD: params.CDFAMILISALD,
            DTMOVEXTCONS: params.DTMOVEXTCONS,
            NRORG: params.NRORG
        },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const AtualizaMovimetacaoExtrato = async function (params, key, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'ATUALIZA_MOVIMENTACAO_EXTRATO',
        binds: {
            SALDOFINAL: params.SALDOFINAL,
            CDCLIENTE: params.CDCLIENTE,
            CDCONSUMIDOR: params.CDCONSUMIDOR,
            CDFAMILISALD: params.CDFAMILISALD,
            DTMOVEXTCONS: params.DTMOVEXTCONS,
            NRSEQMOVEXT: params.NRSEQMOVEXT,
            NRORG: params.NRORG
        },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const GetVerificaSaldo = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'GET_VERIFICA_SALDO',
        binds: {
            CDCLIENTE: params.CDCLIENTE,
            CDCONSUMIDOR: params.CDCONSUMIDOR,
            CDFAMILISALD: params.CDFAMILISALD,
            NRORG: params.NRORG
        },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })
    
    return result
}

const InsertSaldoCons = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'INSERT_SALDO_CONS',
        binds: {
            CDCLIENTE: params.CDCLIENTE,
            CDCONSUMIDOR: params.CDCONSUMIDOR,
            CDFAMILISALD: params.CDFAMILISALD,
            VRSALDCONFAM: params.SALDOFINAL,
            NRORG: params.NRORG
        },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}

const AtualizaSaldoCons = async function (params, autoCommit = true, connectionKey) {
    const result = await executeQuery({
        sql: 'ATUALIZA_SALDO_CONS',
        binds: {
            CDCLIENTE: params.CDCLIENTE,
            CDCONSUMIDOR: params.CDCONSUMIDOR,
            CDFAMILISALD: params.CDFAMILISALD,
            VRSALDCONFAM: params.SALDOFINAL,
            NRORG: params.NRORG
        },
        rawReturn: true,
        autoCommit: autoCommit,
        connectionKey
    })

    return result
}
export default { getTransactionDateF, getConsumerNrorg, getSaldoAllFamilies, getSaldoForFamilie, AtualizaMovimetacaoExtrato, GetVerificaSaldo, InsertSaldoCons, AtualizaSaldoCons }