import { executeQuery } from '../Connection/QueriesExecutor.js'
import pdf2base64 from 'pdf-to-base64';

const getSubscriptionServices = async function ({ CDFILIAL }) {
    let result = await executeQuery({ sql: 'GET_SUBSCRIPTION_SERVICES',
        rawReturn: true,
        binds: {
            'CDFILIAL': CDFILIAL
        }
    })
    const terms = result.map(s => { return { URLARQTERMO: s.URLARQTERMO, FILESERVERURL: s.FILESERVERURL, NMSERVASS: s.NMSERVASS } })
    for (let i = 0; i < terms.length; i++) {
        const term = terms[i];
        if (term.URLARQTERMO.includes('/TermoAssinatura/')) {
            result[i].bs64 = await pdf2base64(term.FILESERVERURL + term.URLARQTERMO).then(f => f).catch(e => [])
        } 
    }
    return result
}

const insertServicoAssinaturaCliente = async ({ CDCLIENTE, CDFILIAL, CDCONSUMIDOR, NRCPFRESPCON, NRSERVASSCLI, VLRASS, DTASSINATURA }) => {
    let result = await executeQuery({ sql: 'INSERT_SERVICO_ASSINATURA_CLIENTE',
        rawReturn: true,
        binds: {
            'CDCLIENTE': CDCLIENTE,
            'CDFILIAL': CDFILIAL,
            'CDCONSUMIDOR': CDCONSUMIDOR,
            'NRCPFRESPCON': NRCPFRESPCON,
            'NRSERVASSCLI': NRSERVASSCLI,
            'VLRASS': VLRASS,
            'DTASSINATURA': DTASSINATURA
        }
    })

    return result
}

const insertServicoAssinaturaAssoc = async ({ NRSERVASSCLI, NRSERVASS, VRNCSERVASS, NUMPARCELAS }) => {
    let result = await executeQuery({ sql: 'INSERT_SERVICO_ASSINATURA_ASSOC',
        rawReturn: true,
        binds: {
            'NRSERVASSCLI': NRSERVASSCLI,
            'NRSERVASS': NRSERVASS,
            'VRNCSERVASS': VRNCSERVASS,
            'NUMPARCELAS': NUMPARCELAS
        }
    })

    return result
}

const getSubscribedServicesByConsumer = async ({ CDCLIENTE, CDFILIAL, CDCONSUMIDOR, NRCPFRESPCON }) => {
    let result = await executeQuery({ sql: 'GET_SUBSCRIBED_SERVICES_BY_CONSUMER',
        rawReturn: true,
        binds: { CDCLIENTE, CDFILIAL, CDCONSUMIDOR, NRCPFRESPCON }
    })

    return result
}

const hasAnySubscriptionService = async function ({ CDFILIAL }) {
    let result = await executeQuery({
        sql: 'CHECK_HAS_SUBSCRIPTION',
        rawReturn: true,
        binds: {
            'CDFILIAL': CDFILIAL
        }
    })
    return result
}
export default {
    getSubscriptionServices,
    insertServicoAssinaturaCliente,
    insertServicoAssinaturaAssoc,
    getSubscribedServicesByConsumer,
    hasAnySubscriptionService
}
